[gjs: 9/43] CI: Use camelcase
- From: Philip Chimento <pchimento src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [gjs: 9/43] CI: Use camelcase
- Date: Wed, 14 Aug 2019 17:27:49 +0000 (UTC)
commit fddfa4bf3b27b902eb2b9c6a5a2214eb58b5527c
Author: Philip Chimento <philip chimento gmail com>
Date: Tue Aug 13 22:00:05 2019 -0700
CI: Use camelcase
Use camelcase variables everywhere, but don't yet enable the rule for
real; it hasn't been in eslint that long and not all distributions have
caught up.
.eslintrc.yml | 5 +
examples/calc.js | 130 ++++++++++----------
examples/gtk-application.js | 4 +-
installed-tests/js/minijasmine.js | 12 +-
installed-tests/js/testEverythingBasic.js | 10 +-
installed-tests/js/testEverythingEncapsulated.js | 50 ++++----
installed-tests/js/testGDBus.js | 20 ++--
installed-tests/js/testGIMarshalling.js | 4 +-
installed-tests/js/testGLib.js | 36 +++---
installed-tests/js/testGObjectClass.js | 32 ++---
installed-tests/js/testGTypeClass.js | 6 +-
installed-tests/js/testGio.js | 8 +-
installed-tests/js/testGtk.js | 4 +-
installed-tests/js/testLegacyGObject.js | 20 ++--
installed-tests/js/testTweener.js | 9 +-
modules/mainloop.js | 7 ++
modules/overrides/GLib.js | 51 ++++----
modules/overrides/GObject.js | 68 +++++------
modules/overrides/Gio.js | 72 ++++++------
modules/signals.js | 4 +-
modules/tweener/equations.js | 144 +++++++++++------------
test/gjs-test-coverage/loadedJSFromResource.js | 4 +-
22 files changed, 356 insertions(+), 344 deletions(-)
---
diff --git a/.eslintrc.yml b/.eslintrc.yml
index cf55198e..d1e5d6a8 100644
--- a/.eslintrc.yml
+++ b/.eslintrc.yml
@@ -15,6 +15,11 @@ rules:
arrow-spacing: error
block-scoped-var: error
brace-style: error
+ # Waiting for this to have matured a bit in eslint
+ # camelcase:
+ # - error
+ # - properties: never
+ # allow: [^vfunc_, ^on_, _instance_init]
comma-spacing:
- error
- before: false
diff --git a/examples/calc.js b/examples/calc.js
index 57c30fc5..54f88836 100644
--- a/examples/calc.js
+++ b/examples/calc.js
@@ -5,61 +5,61 @@ const {Gtk} = imports.gi;
Gtk.init(null);
-var calc_val = '';
+var calcVal = '';
-function update_display() {
- label.set_markup(`<span size='30000'>${calc_val}</span>`);
+function updateDisplay() {
+ label.set_markup(`<span size='30000'>${calcVal}</span>`);
- if (calc_val === '') {
+ if (calcVal === '') {
label.set_markup("<span size='30000'>0</span>");
}
}
function clear() {
- calc_val = '';
- update_display();
+ calcVal = '';
+ updateDisplay();
}
function backspace() {
- calc_val = calc_val.substring(0, calc_val.length - 1);
- update_display();
+ calcVal = calcVal.substring(0, calcVal.length - 1);
+ updateDisplay();
}
-function pressed_equals() {
- calc_val = calc_val.replace('sin', 'Math.sin');
- calc_val = calc_val.replace('cos', 'Math.cos');
- calc_val = calc_val.replace('tan', 'Math.tan');
- calc_val = eval(calc_val);
+function pressedEquals() {
+ calcVal = calcVal.replace('sin', 'Math.sin');
+ calcVal = calcVal.replace('cos', 'Math.cos');
+ calcVal = calcVal.replace('tan', 'Math.tan');
+ calcVal = eval(calcVal);
// Avoid ridiculous amounts of precision from toString.
- if (calc_val == Math.floor(calc_val))
- calc_val = Math.floor(calc_val);
+ if (calcVal == Math.floor(calcVal))
+ calcVal = Math.floor(calcVal);
else // bizarrely gjs loses str.toFixed() somehow?!
- calc_val = Math.floor(calc_val * 10000) / 10000;
- label.set_markup(`<span size='30000'>${calc_val}</span>`);
+ calcVal = Math.floor(calcVal * 10000) / 10000;
+ label.set_markup(`<span size='30000'>${calcVal}</span>`);
}
-function pressed_operator(button) {
- calc_val += button.label;
- update_display();
+function pressedOperator(button) {
+ calcVal += button.label;
+ updateDisplay();
}
-function pressed_number(button) {
- calc_val = (((calc_val === 0) ? '' : calc_val) + button.label);
- update_display();
+function pressedNumber(button) {
+ calcVal = (((calcVal === 0) ? '' : calcVal) + button.label);
+ updateDisplay();
}
-function swap_sign() {
- calc_val = ((calc_val[0] == '-') ?
- calc_val.substring(1) : `-${calc_val}`);
- update_display();
+function swapSign() {
+ calcVal = ((calcVal[0] == '-') ?
+ calcVal.substring(1) : `-${calcVal}`);
+ updateDisplay();
}
-function random_num() {
- calc_val = `${Math.floor(Math.random() * 1000)}`;
- update_display();
+function randomNum() {
+ calcVal = `${Math.floor(Math.random() * 1000)}`;
+ updateDisplay();
}
-function pack_buttons(buttons, vbox) {
+function packButtons(buttons, vbox) {
var hbox = new Gtk.HBox();
hbox.homogeneous = true;
@@ -71,53 +71,53 @@ function pack_buttons(buttons, vbox) {
}
}
-function create_button(str, func) {
+function createButton(str, func) {
var btn = new Gtk.Button({label: str});
btn.connect('clicked', func);
return btn;
}
-function create_buttons() {
+function createButtons() {
var vbox = new Gtk.VBox({homogeneous: true});
- pack_buttons([
- create_button('(', pressed_number),
- create_button('←', backspace),
- create_button('↻', random_num),
- create_button('Clr', clear),
- create_button('±', swap_sign)
+ packButtons([
+ createButton('(', pressedNumber),
+ createButton('←', backspace),
+ createButton('↻', randomNum),
+ createButton('Clr', clear),
+ createButton('±', swapSign)
], vbox);
- pack_buttons([
- create_button(')', pressed_number),
- create_button('7', pressed_number),
- create_button('8', pressed_number),
- create_button('9', pressed_number),
- create_button('/', pressed_operator)
+ packButtons([
+ createButton(')', pressedNumber),
+ createButton('7', pressedNumber),
+ createButton('8', pressedNumber),
+ createButton('9', pressedNumber),
+ createButton('/', pressedOperator)
], vbox);
- pack_buttons([
- create_button('sin(', pressed_number),
- create_button('4', pressed_number),
- create_button('5', pressed_number),
- create_button('6', pressed_number),
- create_button('*', pressed_operator)
+ packButtons([
+ createButton('sin(', pressedNumber),
+ createButton('4', pressedNumber),
+ createButton('5', pressedNumber),
+ createButton('6', pressedNumber),
+ createButton('*', pressedOperator)
], vbox);
- pack_buttons([
- create_button('cos(', pressed_number),
- create_button('1', pressed_number),
- create_button('2', pressed_number),
- create_button('3', pressed_number),
- create_button('-', pressed_operator)
+ packButtons([
+ createButton('cos(', pressedNumber),
+ createButton('1', pressedNumber),
+ createButton('2', pressedNumber),
+ createButton('3', pressedNumber),
+ createButton('-', pressedOperator)
], vbox);
- pack_buttons([
- create_button('tan(', pressed_number),
- create_button('0', pressed_number),
- create_button('.', pressed_number),
- create_button('=', pressed_equals),
- create_button('+', pressed_operator)
+ packButtons([
+ createButton('tan(', pressedNumber),
+ createButton('0', pressedNumber),
+ createButton('.', pressedNumber),
+ createButton('=', pressedEquals),
+ createButton('+', pressedOperator)
], vbox);
return vbox;
@@ -134,12 +134,12 @@ win.connect('destroy', () => Gtk.main_quit());
var label = new Gtk.Label({label: ''});
label.set_alignment(1, 0);
-update_display();
+updateDisplay();
var mainvbox = new Gtk.VBox();
mainvbox.pack_start(label, false, true, 1);
mainvbox.pack_start(new Gtk.HSeparator(), false, true, 5);
-mainvbox.pack_start(create_buttons(), true, true, 2);
+mainvbox.pack_start(createButtons(), true, true, 2);
win.add(mainvbox);
win.show_all();
diff --git a/examples/gtk-application.js b/examples/gtk-application.js
index 4e81183d..a9b3251c 100644
--- a/examples/gtk-application.js
+++ b/examples/gtk-application.js
@@ -49,7 +49,7 @@ var ExampleApplication = GObject.registerClass({
}
// Example signal emission
- emit_examplesig(number) {
+ emitExamplesig(number) {
this.emit('examplesig', number);
}
@@ -63,7 +63,7 @@ var ExampleApplication = GObject.registerClass({
});
exampleAction.connect('activate', (action, param) => {
- param = param.deep_unpack().toString();
+ param = param.deepUnpack().toString();
if (param === 'exampleParameter') {
log('Yes!');
diff --git a/installed-tests/js/minijasmine.js b/installed-tests/js/minijasmine.js
index f028d012..6e7b92b3 100644
--- a/installed-tests/js/minijasmine.js
+++ b/installed-tests/js/minijasmine.js
@@ -84,19 +84,19 @@ class TapReporter {
}
specDone(result) {
- let tap_report;
+ let tapReport;
if (result.status === 'failed') {
window._jasmineRetval = 1;
- tap_report = 'not ok';
+ tapReport = 'not ok';
} else {
- tap_report = 'ok';
+ tapReport = 'ok';
}
- tap_report += ` ${this._specCount} ${result.fullName}`;
+ tapReport += ` ${this._specCount} ${result.fullName}`;
if (result.status === 'pending' || result.status === 'disabled') {
let reason = result.pendingReason || result.status;
- tap_report += ` # SKIP ${reason}`;
+ tapReport += ` # SKIP ${reason}`;
}
- print(tap_report);
+ print(tapReport);
// Print additional diagnostic info on failure
if (result.status === 'failed' && result.failedExpectations) {
diff --git a/installed-tests/js/testEverythingBasic.js b/installed-tests/js/testEverythingBasic.js
index 9f13351a..3332d91c 100644
--- a/installed-tests/js/testEverythingBasic.js
+++ b/installed-tests/js/testEverythingBasic.js
@@ -85,7 +85,7 @@ describe('Life, the Universe and Everything', function () {
'MAX64': true, // FAIL: expected 9223372036854776000, got -9223372036854776000
};
- function run_test(bytes, limit, method_stem) {
+ function runTest(bytes, limit, methodStem) {
if (skip[limit + bytes])
pending("This test doesn't work");
@@ -94,7 +94,7 @@ describe('Life, the Universe and Everything', function () {
'*cannot be safely stored*');
let val = Limits[bytes][limit];
- expect(Regress[method_stem + bytes](val)).toBe(val);
+ expect(Regress[methodStem + bytes](val)).toBe(val);
if (bytes === '64')
GLib.test_assert_expected_messages_internal('Gjs',
@@ -102,15 +102,15 @@ describe('Life, the Universe and Everything', function () {
}
['8', '16', '32', '64'].forEach(bytes => {
it(`marshals max value of unsigned ${bytes}-bit integers`, function () {
- run_test(bytes, 'UMAX', 'test_uint');
+ runTest(bytes, 'UMAX', 'test_uint');
});
it(`marshals min value of signed ${bytes}-bit integers`, function () {
- run_test(bytes, 'MIN', 'test_int');
+ runTest(bytes, 'MIN', 'test_int');
});
it(`marshals max value of signed ${bytes}-bit integers`, function () {
- run_test(bytes, 'MAX', 'test_int');
+ runTest(bytes, 'MAX', 'test_int');
});
});
diff --git a/installed-tests/js/testEverythingEncapsulated.js
b/installed-tests/js/testEverythingEncapsulated.js
index fdb455db..8b977833 100644
--- a/installed-tests/js/testEverythingEncapsulated.js
+++ b/installed-tests/js/testEverythingEncapsulated.js
@@ -87,18 +87,18 @@ describe('Introspected structs', function () {
});
describe('Introspected boxed types', function () {
- let simple_boxed;
+ let simpleBoxed;
it('sets fields correctly', function () {
- simple_boxed = new Regress.TestSimpleBoxedA();
- simple_boxed.some_int = 42;
- simple_boxed.some_int8 = 43;
- simple_boxed.some_double = 42.5;
- simple_boxed.some_enum = Regress.TestEnum.VALUE3;
- expect(simple_boxed.some_int).toEqual(42);
- expect(simple_boxed.some_int8).toEqual(43);
- expect(simple_boxed.some_double).toEqual(42.5);
- expect(simple_boxed.some_enum).toEqual(Regress.TestEnum.VALUE3);
+ simpleBoxed = new Regress.TestSimpleBoxedA();
+ simpleBoxed.some_int = 42;
+ simpleBoxed.some_int8 = 43;
+ simpleBoxed.some_double = 42.5;
+ simpleBoxed.some_enum = Regress.TestEnum.VALUE3;
+ expect(simpleBoxed.some_int).toEqual(42);
+ expect(simpleBoxed.some_int8).toEqual(43);
+ expect(simpleBoxed.some_double).toEqual(42.5);
+ expect(simpleBoxed.some_enum).toEqual(Regress.TestEnum.VALUE3);
let boxed = new Regress.TestBoxed();
boxed.some_int8 = 42;
@@ -107,7 +107,7 @@ describe('Introspected boxed types', function () {
describe('copy constructors', function () {
beforeEach(function () {
- simple_boxed = new Regress.TestSimpleBoxedA({
+ simpleBoxed = new Regress.TestSimpleBoxedA({
some_int: 42,
some_int8: 43,
some_double: 42.5,
@@ -116,10 +116,10 @@ describe('Introspected boxed types', function () {
});
it('"copies" an object from a hash of field values', function () {
- expect(simple_boxed.some_int).toEqual(42);
- expect(simple_boxed.some_int8).toEqual(43);
- expect(simple_boxed.some_double).toEqual(42.5);
- expect(simple_boxed.some_enum).toEqual(Regress.TestEnum.VALUE3);
+ expect(simpleBoxed.some_int).toEqual(42);
+ expect(simpleBoxed.some_int8).toEqual(43);
+ expect(simpleBoxed.some_double).toEqual(42.5);
+ expect(simpleBoxed.some_enum).toEqual(Regress.TestEnum.VALUE3);
});
it('catches bad field names', function () {
@@ -127,7 +127,7 @@ describe('Introspected boxed types', function () {
});
it('copies an object from another object of the same type', function () {
- let copy = new Regress.TestSimpleBoxedA(simple_boxed);
+ let copy = new Regress.TestSimpleBoxedA(simpleBoxed);
expect(copy instanceof Regress.TestSimpleBoxedA).toBeTruthy();
expect(copy.some_int).toEqual(42);
expect(copy.some_int8).toEqual(43);
@@ -138,24 +138,24 @@ describe('Introspected boxed types', function () {
describe('nested', function () {
beforeEach(function () {
- simple_boxed = new Regress.TestSimpleBoxedB();
+ simpleBoxed = new Regress.TestSimpleBoxedB();
});
it('reads fields and nested fields', function () {
- simple_boxed.some_int8 = 42;
- simple_boxed.nested_a.some_int = 43;
- expect(simple_boxed.some_int8).toEqual(42);
- expect(simple_boxed.nested_a.some_int).toEqual(43);
+ simpleBoxed.some_int8 = 42;
+ simpleBoxed.nested_a.some_int = 43;
+ expect(simpleBoxed.some_int8).toEqual(42);
+ expect(simpleBoxed.nested_a.some_int).toEqual(43);
});
it('assigns nested struct field from an instance', function () {
- simple_boxed.nested_a = new Regress.TestSimpleBoxedA({some_int: 53});
- expect(simple_boxed.nested_a.some_int).toEqual(53);
+ simpleBoxed.nested_a = new Regress.TestSimpleBoxedA({some_int: 53});
+ expect(simpleBoxed.nested_a.some_int).toEqual(53);
});
it('assigns nested struct field directly from a hash of field values', function () {
- simple_boxed.nested_a = {some_int: 63};
- expect(simple_boxed.nested_a.some_int).toEqual(63);
+ simpleBoxed.nested_a = {some_int: 63};
+ expect(simpleBoxed.nested_a.some_int).toEqual(63);
});
});
diff --git a/installed-tests/js/testGDBus.js b/installed-tests/js/testGDBus.js
index 65597f2f..6be052fe 100644
--- a/installed-tests/js/testGDBus.js
+++ b/installed-tests/js/testGDBus.js
@@ -213,7 +213,7 @@ class Test {
}
set PropReadWrite(value) {
- this._propReadWrite = value.deep_unpack();
+ this._propReadWrite = value.deepUnpack();
}
structArray() {
@@ -257,7 +257,7 @@ class Test {
const ProxyClass = Gio.DBusProxy.makeProxyWrapper(TestIface);
describe('Exported DBus object', function () {
- var own_name_id;
+ let ownNameID;
var test;
var proxy;
let loop;
@@ -283,7 +283,7 @@ describe('Exported DBus object', function () {
loop = new GLib.MainLoop(null, false);
test = new Test();
- own_name_id = Gio.DBus.session.own_name('org.gnome.gjs.Test',
+ ownNameID = Gio.DBus.session.own_name('org.gnome.gjs.Test',
Gio.BusNameOwnerFlags.NONE,
name => {
log(`Acquired name ${name}`);
@@ -308,7 +308,7 @@ describe('Exported DBus object', function () {
afterAll(function () {
// Not really needed, but if we don't cleanup
// memory checking will complain
- Gio.DBus.session.unown_name(own_name_id);
+ Gio.DBus.session.unown_name(ownNameID);
});
beforeEach(function () {
@@ -318,7 +318,7 @@ describe('Exported DBus object', function () {
it('can call a remote method', function () {
proxy.frobateStuffRemote({}, ([result], excp) => {
expect(excp).toBeNull();
- expect(result.hello.deep_unpack()).toEqual('world');
+ expect(result.hello.deepUnpack()).toEqual('world');
loop.quit();
});
loop.run();
@@ -343,7 +343,7 @@ describe('Exported DBus object', function () {
otherProxy.frobateStuffRemote({}, ([result], excp) => {
expect(excp).toBeNull();
- expect(result.hello.deep_unpack()).toEqual('world');
+ expect(result.hello.deepUnpack()).toEqual('world');
loop.quit();
});
loop.run();
@@ -541,13 +541,13 @@ describe('Exported DBus object', function () {
expect(result).not.toBeNull();
// verify the fractional part was dropped off int
- expect(result['anInteger'].deep_unpack()).toEqual(10);
+ expect(result['anInteger'].deepUnpack()).toEqual(10);
// and not dropped off a double
- expect(result['aDoubleBeforeAndAfter'].deep_unpack()).toEqual(10.5);
+ expect(result['aDoubleBeforeAndAfter'].deepUnpack()).toEqual(10.5);
// check without type conversion
- expect(result['aDouble'].deep_unpack()).toBe(10.0);
+ expect(result['aDouble'].deepUnpack()).toBe(10.0);
loop.quit();
});
@@ -638,7 +638,7 @@ describe('Exported DBus object', function () {
proxy.PropReadWrite = GLib.Variant.new_string(testStr);
}).not.toThrow();
- expect(proxy.PropReadWrite.deep_unpack()).toEqual(testStr);
+ expect(proxy.PropReadWrite.deepUnpack()).toEqual(testStr);
expect(waitForServerProperty('_propReadWrite', testStr)).toEqual(testStr);
});
diff --git a/installed-tests/js/testGIMarshalling.js b/installed-tests/js/testGIMarshalling.js
index 4de1b045..be6c6fe8 100644
--- a/installed-tests/js/testGIMarshalling.js
+++ b/installed-tests/js/testGIMarshalling.js
@@ -607,10 +607,10 @@ const VFuncTester = GObject.registerClass(class VFuncTester extends GIMarshallin
case -1:
return true;
case 0:
- undefined.throw_type_error();
+ undefined.throwTypeError();
break;
case 1:
- void reference_error; // eslint-disable-line no-undef
+ void referenceError; // eslint-disable-line no-undef
break;
case 2:
throw new Gio.IOErrorEnum({
diff --git a/installed-tests/js/testGLib.js b/installed-tests/js/testGLib.js
index 602cff16..3fd57fcc 100644
--- a/installed-tests/js/testGLib.js
+++ b/installed-tests/js/testGLib.js
@@ -3,61 +3,61 @@ const GLib = imports.gi.GLib;
describe('GVariant constructor', function () {
it('constructs a string variant', function () {
- let str_variant = new GLib.Variant('s', 'mystring');
- expect(str_variant.get_string()[0]).toEqual('mystring');
- expect(str_variant.deep_unpack()).toEqual('mystring');
+ let strVariant = new GLib.Variant('s', 'mystring');
+ expect(strVariant.get_string()[0]).toEqual('mystring');
+ expect(strVariant.deepUnpack()).toEqual('mystring');
});
it('constructs a string variant (backwards compatible API)', function () {
- let str_variant = new GLib.Variant('s', 'mystring');
- let str_variant_old = GLib.Variant.new('s', 'mystring');
- expect(str_variant.equal(str_variant_old)).toBeTruthy();
+ let strVariant = new GLib.Variant('s', 'mystring');
+ let strVariantOld = GLib.Variant.new('s', 'mystring');
+ expect(strVariant.equal(strVariantOld)).toBeTruthy();
});
it('constructs a struct variant', function () {
- let struct_variant = new GLib.Variant('(sogvau)', [
+ let structVariant = new GLib.Variant('(sogvau)', [
'a string',
'/a/object/path',
'asig', //nature
new GLib.Variant('s', 'variant'),
[7, 3]
]);
- expect(struct_variant.n_children()).toEqual(5);
+ expect(structVariant.n_children()).toEqual(5);
- let unpacked = struct_variant.deep_unpack();
+ let unpacked = structVariant.deepUnpack();
expect(unpacked[0]).toEqual('a string');
expect(unpacked[1]).toEqual('/a/object/path');
expect(unpacked[2]).toEqual('asig');
expect(unpacked[3] instanceof GLib.Variant).toBeTruthy();
- expect(unpacked[3].deep_unpack()).toEqual('variant');
+ expect(unpacked[3].deepUnpack()).toEqual('variant');
expect(unpacked[4] instanceof Array).toBeTruthy();
expect(unpacked[4].length).toEqual(2);
});
it('constructs a maybe variant', function () {
- let maybe_variant = new GLib.Variant('ms', null);
- expect(maybe_variant.deep_unpack()).toBeNull();
+ let maybeVariant = new GLib.Variant('ms', null);
+ expect(maybeVariant.deepUnpack()).toBeNull();
- maybe_variant = new GLib.Variant('ms', 'string');
- expect(maybe_variant.deep_unpack()).toEqual('string');
+ maybeVariant = new GLib.Variant('ms', 'string');
+ expect(maybeVariant.deepUnpack()).toEqual('string');
});
it('constructs a byte array variant', function () {
const byteArray = Uint8Array.from('pizza', c => c.charCodeAt(0));
const byteArrayVariant = new GLib.Variant('ay', byteArray);
- expect(ByteArray.toString(byteArrayVariant.deep_unpack()))
+ expect(ByteArray.toString(byteArrayVariant.deepUnpack()))
.toEqual('pizza');
});
it('constructs a byte array variant from a string', function () {
const byteArrayVariant = new GLib.Variant('ay', 'pizza');
- expect(ByteArray.toString(byteArrayVariant.deep_unpack()))
+ expect(ByteArray.toString(byteArrayVariant.deepUnpack()))
.toEqual('pizza');
});
it('0-terminates a byte array variant constructed from a string', function () {
const byteArrayVariant = new GLib.Variant('ay', 'pizza');
- const a = byteArrayVariant.deep_unpack();
+ const a = byteArrayVariant.deepUnpack();
[112, 105, 122, 122, 97, 0].forEach((val, ix) =>
expect(a[ix]).toEqual(val));
});
@@ -65,7 +65,7 @@ describe('GVariant constructor', function () {
it('does not 0-terminate a byte array variant constructed from a Uint8Array', function () {
const byteArray = Uint8Array.from('pizza', c => c.charCodeAt(0));
const byteArrayVariant = new GLib.Variant('ay', byteArray);
- const a = byteArrayVariant.deep_unpack();
+ const a = byteArrayVariant.deepUnpack();
[112, 105, 122, 122, 97].forEach((val, ix) =>
expect(a[ix]).toEqual(val));
});
diff --git a/installed-tests/js/testGObjectClass.js b/installed-tests/js/testGObjectClass.js
index 852501b4..b017b4f8 100644
--- a/installed-tests/js/testGObjectClass.js
+++ b/installed-tests/js/testGObjectClass.js
@@ -72,30 +72,30 @@ const MyObject = GObject.registerClass({
this._constructCalled = true;
}
- notify_prop() {
+ notifyProp() {
this._readonly = 'changed';
this.notify('readonly');
}
- emit_empty() {
+ emitEmpty() {
this.emit('empty');
}
- emit_minimal(one, two) {
+ emitMinimal(one, two) {
this.emit('minimal', one, two);
}
- emit_full() {
+ emitFull() {
return this.emit('full');
}
- emit_detailed() {
+ emitDetailed() {
this.emit('detailed::one');
this.emit('detailed::two');
}
- emit_run_last(callback) {
+ emitRunLast(callback) {
this._run_last_callback = callback;
this.emit('run-last');
}
@@ -122,7 +122,7 @@ const MyAbstractObject = GObject.registerClass({
const MyApplication = GObject.registerClass({
Signals: {'custom': {param_types: [GObject.TYPE_INT]}},
}, class MyApplication extends Gio.Application {
- emit_custom(n) {
+ emitCustom(n) {
this.emit('custom', n);
}
});
@@ -207,8 +207,8 @@ describe('GObject class with decorator', function () {
let notifySpy = jasmine.createSpy('notifySpy');
myInstance.connect('notify::readonly', notifySpy);
- myInstance.notify_prop();
- myInstance.notify_prop();
+ myInstance.notifyProp();
+ myInstance.notifyProp();
expect(notifySpy).toHaveBeenCalledTimes(2);
});
@@ -216,7 +216,7 @@ describe('GObject class with decorator', function () {
it('can define its own signals', function () {
let emptySpy = jasmine.createSpy('emptySpy');
myInstance.connect('empty', emptySpy);
- myInstance.emit_empty();
+ myInstance.emitEmpty();
expect(emptySpy).toHaveBeenCalled();
expect(myInstance.empty_called).toBeTruthy();
@@ -225,7 +225,7 @@ describe('GObject class with decorator', function () {
it('passes emitted arguments to signal handlers', function () {
let minimalSpy = jasmine.createSpy('minimalSpy');
myInstance.connect('minimal', minimalSpy);
- myInstance.emit_minimal(7, 5);
+ myInstance.emitMinimal(7, 5);
expect(minimalSpy).toHaveBeenCalledWith(myInstance, 7, 5);
});
@@ -233,7 +233,7 @@ describe('GObject class with decorator', function () {
it('can return values from signals', function () {
let fullSpy = jasmine.createSpy('fullSpy').and.returnValue(42);
myInstance.connect('full', fullSpy);
- let result = myInstance.emit_full();
+ let result = myInstance.emitFull();
expect(fullSpy).toHaveBeenCalled();
expect(result).toEqual(42);
@@ -243,14 +243,14 @@ describe('GObject class with decorator', function () {
let neverCalledSpy = jasmine.createSpy('neverCalledSpy');
myInstance.connect('full', () => 42);
myInstance.connect('full', neverCalledSpy);
- myInstance.emit_full();
+ myInstance.emitFull();
expect(neverCalledSpy).not.toHaveBeenCalled();
expect(myInstance.full_default_handler_called).toBeFalsy();
});
it('gets the return value of the default handler', function () {
- let result = myInstance.emit_full();
+ let result = myInstance.emitFull();
expect(myInstance.full_default_handler_called).toBeTruthy();
expect(result).toEqual(79);
@@ -263,7 +263,7 @@ describe('GObject class with decorator', function () {
stack.push(1);
});
myInstance.connect('run-last', runLastSpy);
- myInstance.emit_run_last(() => {
+ myInstance.emitRunLast(() => {
stack.push(2);
});
@@ -276,7 +276,7 @@ describe('GObject class with decorator', function () {
let customSpy = jasmine.createSpy('customSpy');
instance.connect('custom', customSpy);
- instance.emit_custom(73);
+ instance.emitCustom(73);
expect(customSpy).toHaveBeenCalledWith(instance, 73);
});
diff --git a/installed-tests/js/testGTypeClass.js b/installed-tests/js/testGTypeClass.js
index 919ac1e1..3bfe2cd3 100644
--- a/installed-tests/js/testGTypeClass.js
+++ b/installed-tests/js/testGTypeClass.js
@@ -5,9 +5,9 @@ const GObject = imports.gi.GObject;
describe('Looking up param specs', function () {
let p1, p2;
beforeEach(function () {
- let find_property = GObject.Object.find_property;
- p1 = find_property.call(Gio.ThemedIcon, 'name');
- p2 = find_property.call(Gio.SimpleAction, 'enabled');
+ let findProperty = GObject.Object.find_property;
+ p1 = findProperty.call(Gio.ThemedIcon, 'name');
+ p2 = findProperty.call(Gio.SimpleAction, 'enabled');
});
it('works', function () {
diff --git a/installed-tests/js/testGio.js b/installed-tests/js/testGio.js
index b52358c1..d19bc1d9 100644
--- a/installed-tests/js/testGio.js
+++ b/installed-tests/js/testGio.js
@@ -108,7 +108,7 @@ describe('Gio.Settings overrides', function () {
settings.set_boolean('fullscreen', true);
}).not.toThrow();
- expect(settings.get_value('window-size').deep_unpack()).toEqual([100, 100]);
+ expect(settings.get_value('window-size').deepUnpack()).toEqual([100, 100]);
expect(settings.get_boolean('maximized')).toEqual(true);
expect(settings.get_boolean('fullscreen')).toEqual(true);
@@ -117,9 +117,9 @@ describe('Gio.Settings overrides', function () {
}).not.toThrow();
KEYS.forEach(key => expect(settings.get_user_value(key)).toBeNull());
- expect(settings.get_default_value('window-size').deep_unpack()).toEqual([-1, -1]);
- expect(settings.get_default_value('maximized').deep_unpack()).toEqual(false);
- expect(settings.get_default_value('fullscreen').deep_unpack()).toEqual(false);
+ expect(settings.get_default_value('window-size').deepUnpack()).toEqual([-1, -1]);
+ expect(settings.get_default_value('maximized').deepUnpack()).toEqual(false);
+ expect(settings.get_default_value('fullscreen').deepUnpack()).toEqual(false);
const foo = new Foo({boolval: true});
settings.bind('maximized', foo, 'boolval', Gio.SettingsBindFlags.GET);
diff --git a/installed-tests/js/testGtk.js b/installed-tests/js/testGtk.js
index 02b89ff2..deede7c6 100755
--- a/installed-tests/js/testGtk.js
+++ b/installed-tests/js/testGtk.js
@@ -76,8 +76,8 @@ const MyComplexGtkSubclassFromResource = GObject.registerClass({
});
const [templateFile, stream] = Gio.File.new_tmp(null);
-const base_stream = stream.get_output_stream();
-const out = new Gio.DataOutputStream({base_stream});
+const baseStream = stream.get_output_stream();
+const out = new Gio.DataOutputStream({baseStream});
out.put_string(createTemplate('Gjs_MyComplexGtkSubclassFromFile'), null);
out.close(null);
diff --git a/installed-tests/js/testLegacyGObject.js b/installed-tests/js/testLegacyGObject.js
index d03e744c..c5e5dbb1 100644
--- a/installed-tests/js/testLegacyGObject.js
+++ b/installed-tests/js/testLegacyGObject.js
@@ -817,11 +817,11 @@ const Legacy = new Lang.Class({
this._property = value - 2;
},
- get override_property() {
- return this._override_property + 1;
+ get overrideProperty() {
+ return this._overrideProperty + 1;
},
- set override_property(value) {
- this._override_property = value - 2;
+ set overrideProperty(value) {
+ this._overrideProperty = value - 2;
},
});
Legacy.staticMethod = function () {};
@@ -839,11 +839,11 @@ const Shiny = GObject.registerClass({
overrideMe() {}
- get override_property() {
- return this._override_property + 2;
+ get overrideProperty() {
+ return this._overrideProperty + 2;
}
- set override_property(value) {
- this._override_property = value - 1;
+ set overrideProperty(value) {
+ this._overrideProperty = value - 1;
}
});
@@ -889,8 +889,8 @@ describe('ES6 GObject class inheriting from GObject.Class', function () {
});
it('overrides a property from the parent class', function () {
- instance.override_property = 42;
- expect(instance.override_property).toEqual(43);
+ instance.overrideProperty = 42;
+ expect(instance.overrideProperty).toEqual(43);
});
it('inherits a signal from the parent class', function () {
diff --git a/installed-tests/js/testTweener.js b/installed-tests/js/testTweener.js
index ab0a59bb..62bd7093 100644
--- a/installed-tests/js/testTweener.js
+++ b/installed-tests/js/testTweener.js
@@ -299,15 +299,14 @@ describe('Tweener', function () {
});
it('can register special modifiers for properties', function () {
- Tweener.registerSpecialPropertyModifier('discrete',
- discrete_modifier,
- discrete_get);
- function discrete_modifier(props) {
+ Tweener.registerSpecialPropertyModifier('discrete', discreteModifier,
+ discreteGet);
+ function discreteModifier(props) {
return props.map(function (prop) {
return {name: prop, parameters: null};
});
}
- function discrete_get(begin, end, time) {
+ function discreteGet(begin, end, time) {
return Math.floor(begin + time * (end - begin));
}
diff --git a/modules/mainloop.js b/modules/mainloop.js
index 4437d403..97ef0059 100644
--- a/modules/mainloop.js
+++ b/modules/mainloop.js
@@ -49,6 +49,7 @@ function quit(name) {
loop.quit();
}
+// eslint-disable-next-line camelcase
function idle_source(handler, priority) {
let s = GLib.idle_source_new();
GObject.source_set_closure(s, handler);
@@ -57,10 +58,12 @@ function idle_source(handler, priority) {
return s;
}
+// eslint-disable-next-line camelcase
function idle_add(handler, priority) {
return idle_source(handler, priority).attach(null);
}
+// eslint-disable-next-line camelcase
function timeout_source(timeout, handler, priority) {
let s = GLib.timeout_source_new(timeout);
GObject.source_set_closure(s, handler);
@@ -69,6 +72,7 @@ function timeout_source(timeout, handler, priority) {
return s;
}
+// eslint-disable-next-line camelcase
function timeout_seconds_source(timeout, handler, priority) {
let s = GLib.timeout_source_new_seconds(timeout);
GObject.source_set_closure(s, handler);
@@ -77,14 +81,17 @@ function timeout_seconds_source(timeout, handler, priority) {
return s;
}
+// eslint-disable-next-line camelcase
function timeout_add(timeout, handler, priority) {
return timeout_source(timeout, handler, priority).attach(null);
}
+// eslint-disable-next-line camelcase
function timeout_add_seconds(timeout, handler, priority) {
return timeout_seconds_source(timeout, handler, priority).attach(null);
}
+// eslint-disable-next-line camelcase
function source_remove(id) {
return GLib.source_remove(id);
}
diff --git a/modules/overrides/GLib.js b/modules/overrides/GLib.js
index 3ffa57fe..a59a48ae 100644
--- a/modules/overrides/GLib.js
+++ b/modules/overrides/GLib.js
@@ -24,7 +24,7 @@ let GLib;
const SIMPLE_TYPES = ['b', 'y', 'n', 'q', 'i', 'u', 'x', 't', 'h', 'd', 's', 'o', 'g'];
-function _read_single_type(signature, forceSimple) {
+function _readSingleType(signature, forceSimple) {
let char = signature.shift();
let isSimple = false;
@@ -35,10 +35,10 @@ function _read_single_type(signature, forceSimple) {
isSimple = true;
if (char == 'm' || char == 'a')
- return [char].concat(_read_single_type(signature, false));
+ return [char].concat(_readSingleType(signature, false));
if (char == '{') {
- let key = _read_single_type(signature, true);
- let val = _read_single_type(signature, false);
+ let key = _readSingleType(signature, true);
+ let val = _readSingleType(signature, false);
let close = signature.shift();
if (close != '}')
throw new TypeError('Invalid GVariant signature for type DICT_ENTRY (expected "}"');
@@ -54,7 +54,7 @@ function _read_single_type(signature, forceSimple) {
signature.shift();
return res.concat(next);
}
- let el = _read_single_type(signature);
+ let el = _readSingleType(signature);
res = res.concat(el);
}
}
@@ -73,7 +73,7 @@ function _makeBytes(byteArray) {
return new GLib.Bytes(byteArray);
}
-function _pack_variant(signature, value) {
+function _packVariant(signature, value) {
if (signature.length == 0)
throw new TypeError('GVariant signature cannot be empty');
@@ -109,11 +109,12 @@ function _pack_variant(signature, value) {
return GLib.Variant.new_variant(value);
case 'm':
if (value != null)
- return GLib.Variant.new_maybe(null, _pack_variant(signature, value));
+ return GLib.Variant.new_maybe(null, _packVariant(signature, value));
else
- return GLib.Variant.new_maybe(new GLib.VariantType(_read_single_type(signature,
false).join('')), null);
+ return GLib.Variant.new_maybe(new GLib.VariantType(
+ _readSingleType(signature, false).join('')), null);
case 'a': {
- let arrayType = _read_single_type(signature, false);
+ let arrayType = _readSingleType(signature, false);
if (arrayType[0] == 's') {
// special case for array of strings
return GLib.Variant.new_strv(value);
@@ -138,13 +139,13 @@ function _pack_variant(signature, value) {
// special case for dictionaries
for (let key in value) {
let copy = [].concat(arrayType);
- let child = _pack_variant(copy, [key, value[key]]);
+ let child = _packVariant(copy, [key, value[key]]);
arrayValue.push(child);
}
} else {
for (let i = 0; i < value.length; i++) {
let copy = [].concat(arrayType);
- let child = _pack_variant(copy, value[i]);
+ let child = _packVariant(copy, value[i]);
arrayValue.push(child);
}
}
@@ -157,7 +158,7 @@ function _pack_variant(signature, value) {
let next = signature[0];
if (next == ')')
break;
- children.push(_pack_variant(signature, value[i]));
+ children.push(_packVariant(signature, value[i]));
}
if (signature[0] != ')')
@@ -166,8 +167,8 @@ function _pack_variant(signature, value) {
return GLib.Variant.new_tuple(children);
}
case '{': {
- let key = _pack_variant(signature, value[0]);
- let child = _pack_variant(signature, value[1]);
+ let key = _packVariant(signature, value[0]);
+ let child = _packVariant(signature, value[1]);
if (signature[0] != '}')
throw new TypeError('Invalid GVariant signature for type DICT_ENTRY (expected "}")');
@@ -180,7 +181,7 @@ function _pack_variant(signature, value) {
}
}
-function _unpack_variant(variant, deep, recursive = false) {
+function _unpackVariant(variant, deep, recursive = false) {
switch (String.fromCharCode(variant.classify())) {
case 'b':
return variant.get_boolean();
@@ -210,13 +211,13 @@ function _unpack_variant(variant, deep, recursive = false) {
case 'v': {
const ret = variant.get_variant();
if (deep && recursive && ret instanceof GLib.Variant)
- return _unpack_variant(ret, deep, recursive);
+ return _unpackVariant(ret, deep, recursive);
return ret;
}
case 'm': {
let val = variant.get_maybe();
if (deep && val)
- return _unpack_variant(val, deep, recursive);
+ return _unpackVariant(val, deep, recursive);
else
return val;
}
@@ -228,11 +229,11 @@ function _unpack_variant(variant, deep, recursive = false) {
for (let i = 0; i < nElements; i++) {
// always unpack the dictionary entry, and always unpack
// the key (or it cannot be added as a key)
- let val = _unpack_variant(variant.get_child_value(i), deep,
+ let val = _unpackVariant(variant.get_child_value(i), deep,
recursive);
let key;
if (!deep)
- key = _unpack_variant(val[0], true);
+ key = _unpackVariant(val[0], true);
else
key = val[0];
ret[key] = val[1];
@@ -252,7 +253,7 @@ function _unpack_variant(variant, deep, recursive = false) {
for (let i = 0; i < nElements; i++) {
let val = variant.get_child_value(i);
if (deep)
- ret.push(_unpack_variant(val, deep, recursive));
+ ret.push(_unpackVariant(val, deep, recursive));
else
ret.push(val);
}
@@ -278,7 +279,7 @@ function _init() {
this.Variant._new_internal = function(sig, value) {
let signature = Array.prototype.slice.call(sig);
- let variant = _pack_variant(signature, value);
+ let variant = _packVariant(signature, value);
if (signature.length != 0)
throw new TypeError('Invalid GVariant signature (more than one single complete type)');
@@ -290,17 +291,17 @@ function _init() {
return new GLib.Variant(sig, value);
};
this.Variant.prototype.unpack = function() {
- return _unpack_variant(this, false);
+ return _unpackVariant(this, false);
};
this.Variant.prototype.deepUnpack = function() {
- return _unpack_variant(this, true);
+ return _unpackVariant(this, true);
};
// backwards compatibility alias
this.Variant.prototype.deep_unpack = this.Variant.prototype.deepUnpack;
// Note: discards type information, if the variant contains any 'v' types
this.Variant.prototype.recursiveUnpack = function () {
- return _unpack_variant(this, true, true);
+ return _unpackVariant(this, true, true);
};
this.Variant.prototype.toString = function() {
@@ -327,6 +328,6 @@ function _init() {
const variant = this.lookup_value(key, variantType);
if (variant === null)
return null;
- return _unpack_variant(variant, deep);
+ return _unpackVariant(variant, deep);
};
}
diff --git a/modules/overrides/GObject.js b/modules/overrides/GObject.js
index 5ada6045..f5458692 100644
--- a/modules/overrides/GObject.js
+++ b/modules/overrides/GObject.js
@@ -223,72 +223,72 @@ function _init() {
_makeDummyClass(GObject, 'Type', 'GTYPE', 'GType', GObject.type_from_name);
- GObject.ParamSpec.char = function(name, nick, blurb, flags, minimum, maximum, default_value) {
- return GObject.param_spec_char(name, nick, blurb, minimum, maximum, default_value, flags);
+ GObject.ParamSpec.char = function(name, nick, blurb, flags, minimum, maximum, defaultValue) {
+ return GObject.param_spec_char(name, nick, blurb, minimum, maximum, defaultValue, flags);
};
- GObject.ParamSpec.uchar = function(name, nick, blurb, flags, minimum, maximum, default_value) {
- return GObject.param_spec_uchar(name, nick, blurb, minimum, maximum, default_value, flags);
+ GObject.ParamSpec.uchar = function(name, nick, blurb, flags, minimum, maximum, defaultValue) {
+ return GObject.param_spec_uchar(name, nick, blurb, minimum, maximum, defaultValue, flags);
};
- GObject.ParamSpec.int = function(name, nick, blurb, flags, minimum, maximum, default_value) {
- return GObject.param_spec_int(name, nick, blurb, minimum, maximum, default_value, flags);
+ GObject.ParamSpec.int = function(name, nick, blurb, flags, minimum, maximum, defaultValue) {
+ return GObject.param_spec_int(name, nick, blurb, minimum, maximum, defaultValue, flags);
};
- GObject.ParamSpec.uint = function(name, nick, blurb, flags, minimum, maximum, default_value) {
- return GObject.param_spec_uint(name, nick, blurb, minimum, maximum, default_value, flags);
+ GObject.ParamSpec.uint = function(name, nick, blurb, flags, minimum, maximum, defaultValue) {
+ return GObject.param_spec_uint(name, nick, blurb, minimum, maximum, defaultValue, flags);
};
- GObject.ParamSpec.long = function(name, nick, blurb, flags, minimum, maximum, default_value) {
- return GObject.param_spec_long(name, nick, blurb, minimum, maximum, default_value, flags);
+ GObject.ParamSpec.long = function(name, nick, blurb, flags, minimum, maximum, defaultValue) {
+ return GObject.param_spec_long(name, nick, blurb, minimum, maximum, defaultValue, flags);
};
- GObject.ParamSpec.ulong = function(name, nick, blurb, flags, minimum, maximum, default_value) {
- return GObject.param_spec_ulong(name, nick, blurb, minimum, maximum, default_value, flags);
+ GObject.ParamSpec.ulong = function(name, nick, blurb, flags, minimum, maximum, defaultValue) {
+ return GObject.param_spec_ulong(name, nick, blurb, minimum, maximum, defaultValue, flags);
};
- GObject.ParamSpec.int64 = function(name, nick, blurb, flags, minimum, maximum, default_value) {
- return GObject.param_spec_int64(name, nick, blurb, minimum, maximum, default_value, flags);
+ GObject.ParamSpec.int64 = function(name, nick, blurb, flags, minimum, maximum, defaultValue) {
+ return GObject.param_spec_int64(name, nick, blurb, minimum, maximum, defaultValue, flags);
};
- GObject.ParamSpec.uint64 = function(name, nick, blurb, flags, minimum, maximum, default_value) {
- return GObject.param_spec_uint64(name, nick, blurb, minimum, maximum, default_value, flags);
+ GObject.ParamSpec.uint64 = function(name, nick, blurb, flags, minimum, maximum, defaultValue) {
+ return GObject.param_spec_uint64(name, nick, blurb, minimum, maximum, defaultValue, flags);
};
- GObject.ParamSpec.float = function(name, nick, blurb, flags, minimum, maximum, default_value) {
- return GObject.param_spec_float(name, nick, blurb, minimum, maximum, default_value, flags);
+ GObject.ParamSpec.float = function(name, nick, blurb, flags, minimum, maximum, defaultValue) {
+ return GObject.param_spec_float(name, nick, blurb, minimum, maximum, defaultValue, flags);
};
- GObject.ParamSpec.boolean = function(name, nick, blurb, flags, default_value) {
- return GObject.param_spec_boolean(name, nick, blurb, default_value, flags);
+ GObject.ParamSpec.boolean = function(name, nick, blurb, flags, defaultValue) {
+ return GObject.param_spec_boolean(name, nick, blurb, defaultValue, flags);
};
- GObject.ParamSpec.flags = function(name, nick, blurb, flags, flags_type, default_value) {
- return GObject.param_spec_flags(name, nick, blurb, flags_type, default_value, flags);
+ GObject.ParamSpec.flags = function(name, nick, blurb, flags, flagsType, defaultValue) {
+ return GObject.param_spec_flags(name, nick, blurb, flagsType, defaultValue, flags);
};
- GObject.ParamSpec.enum = function(name, nick, blurb, flags, enum_type, default_value) {
- return GObject.param_spec_enum(name, nick, blurb, enum_type, default_value, flags);
+ GObject.ParamSpec.enum = function(name, nick, blurb, flags, enumType, defaultValue) {
+ return GObject.param_spec_enum(name, nick, blurb, enumType, defaultValue, flags);
};
- GObject.ParamSpec.double = function(name, nick, blurb, flags, minimum, maximum, default_value) {
- return GObject.param_spec_double(name, nick, blurb, minimum, maximum, default_value, flags);
+ GObject.ParamSpec.double = function(name, nick, blurb, flags, minimum, maximum, defaultValue) {
+ return GObject.param_spec_double(name, nick, blurb, minimum, maximum, defaultValue, flags);
};
- GObject.ParamSpec.string = function(name, nick, blurb, flags, default_value) {
- return GObject.param_spec_string(name, nick, blurb, default_value, flags);
+ GObject.ParamSpec.string = function(name, nick, blurb, flags, defaultValue) {
+ return GObject.param_spec_string(name, nick, blurb, defaultValue, flags);
};
- GObject.ParamSpec.boxed = function(name, nick, blurb, flags, boxed_type) {
- return GObject.param_spec_boxed(name, nick, blurb, boxed_type, flags);
+ GObject.ParamSpec.boxed = function(name, nick, blurb, flags, boxedType) {
+ return GObject.param_spec_boxed(name, nick, blurb, boxedType, flags);
};
- GObject.ParamSpec.object = function(name, nick, blurb, flags, object_type) {
- return GObject.param_spec_object(name, nick, blurb, object_type, flags);
+ GObject.ParamSpec.object = function(name, nick, blurb, flags, objectType) {
+ return GObject.param_spec_object(name, nick, blurb, objectType, flags);
};
- GObject.ParamSpec.param = function(name, nick, blurb, flags, param_type) {
- return GObject.param_spec_param(name, nick, blurb, param_type, flags);
+ GObject.ParamSpec.param = function(name, nick, blurb, flags, paramType) {
+ return GObject.param_spec_param(name, nick, blurb, paramType, flags);
};
GObject.ParamSpec.override = Gi.override_property;
diff --git a/modules/signals.js b/modules/signals.js
index 3e086e2a..ea0a2bbb 100644
--- a/modules/signals.js
+++ b/modules/signals.js
@@ -126,7 +126,7 @@ function _emit(name, ...args) {
// which does pass it in. Also if we pass in the emitter here,
// people don't create closures with the emitter in them,
// which would be a cycle.
- let arg_array = [this, ...args];
+ let argArray = [this, ...args];
length = handlers.length;
for (i = 0; i < length; ++i) {
@@ -134,7 +134,7 @@ function _emit(name, ...args) {
if (!connection.disconnected) {
try {
// since we pass "null" for this, the global object will be used.
- let ret = connection.callback.apply(null, arg_array);
+ let ret = connection.callback.apply(null, argArray);
// if the callback returns true, we don't call the next
// signal handlers
diff --git a/modules/tweener/equations.js b/modules/tweener/equations.js
index 49e5cdab..d76f6ee7 100644
--- a/modules/tweener/equations.js
+++ b/modules/tweener/equations.js
@@ -51,13 +51,13 @@ easeOutInSine, easeOutQuad, easeOutQuart, easeOutQuint, easeOutSine, linear */
* @param d Expected easing duration (in frames or seconds).
* @return The correct value.
*/
-function easeNone (t, b, c, d, p_params) {
+function easeNone (t, b, c, d, pParams) {
return c * t / d + b;
}
/* Useful alias */
-function linear (t, b, c, d, p_params) {
- return easeNone (t, b, c, d, p_params);
+function linear (t, b, c, d, pParams) {
+ return easeNone (t, b, c, d, pParams);
}
/**
@@ -69,7 +69,7 @@ function linear (t, b, c, d, p_params) {
* @param d Expected easing duration (in frames or seconds).
* @return The correct value.
*/
-function easeInQuad (t, b, c, d, p_params) {
+function easeInQuad (t, b, c, d, pParams) {
return c * (t /= d) * t + b;
}
@@ -82,7 +82,7 @@ function easeInQuad (t, b, c, d, p_params) {
* @param d Expected easing duration (in frames or seconds).
* @return The correct value.
*/
-function easeOutQuad (t, b, c, d, p_params) {
+function easeOutQuad (t, b, c, d, pParams) {
return -c * (t /= d) * (t - 2) + b;
}
@@ -95,7 +95,7 @@ function easeOutQuad (t, b, c, d, p_params) {
* @param d Expected easing duration (in frames or seconds).
* @return The correct value.
*/
-function easeInOutQuad (t, b, c, d, p_params) {
+function easeInOutQuad (t, b, c, d, pParams) {
if ((t /= d / 2) < 1)
return c / 2 * t * t + b;
return -c / 2 * ((--t) * (t - 2) - 1) + b;
@@ -110,10 +110,10 @@ function easeInOutQuad (t, b, c, d, p_params) {
* @param d Expected easing duration (in frames or seconds).
* @return The correct value.
*/
-function easeOutInQuad (t, b, c, d, p_params) {
+function easeOutInQuad (t, b, c, d, pParams) {
if (t < d / 2)
- return easeOutQuad (t * 2, b, c / 2, d, p_params);
- return easeInQuad((t * 2) - d, b + c / 2, c / 2, d, p_params);
+ return easeOutQuad (t * 2, b, c / 2, d, pParams);
+ return easeInQuad((t * 2) - d, b + c / 2, c / 2, d, pParams);
}
/**
@@ -125,7 +125,7 @@ function easeOutInQuad (t, b, c, d, p_params) {
* @param d Expected easing duration (in frames or seconds).
* @return The correct value.
*/
-function easeInCubic (t, b, c, d, p_params) {
+function easeInCubic (t, b, c, d, pParams) {
return c * (t /= d) * t * t + b;
}
@@ -138,7 +138,7 @@ function easeInCubic (t, b, c, d, p_params) {
* @param d Expected easing duration (in frames or seconds).
* @return The correct value.
*/
-function easeOutCubic (t, b, c, d, p_params) {
+function easeOutCubic (t, b, c, d, pParams) {
return c * ((t = t / d - 1) * t * t + 1) + b;
}
@@ -151,7 +151,7 @@ function easeOutCubic (t, b, c, d, p_params) {
* @param d Expected easing duration (in frames or seconds).
* @return The correct value.
*/
-function easeInOutCubic (t, b, c, d, p_params) {
+function easeInOutCubic (t, b, c, d, pParams) {
if ((t /= d / 2) < 1)
return c / 2 * t * t * t + b;
return c / 2 * ((t -= 2) * t * t + 2) + b;
@@ -166,10 +166,10 @@ function easeInOutCubic (t, b, c, d, p_params) {
* @param d Expected easing duration (in frames or seconds).
* @return The correct value.
*/
-function easeOutInCubic (t, b, c, d, p_params) {
+function easeOutInCubic (t, b, c, d, pParams) {
if (t < d / 2)
- return easeOutCubic (t * 2, b, c / 2, d, p_params);
- return easeInCubic((t * 2) - d, b + c / 2, c / 2, d, p_params);
+ return easeOutCubic (t * 2, b, c / 2, d, pParams);
+ return easeInCubic((t * 2) - d, b + c / 2, c / 2, d, pParams);
}
/**
@@ -181,7 +181,7 @@ function easeOutInCubic (t, b, c, d, p_params) {
* @param d Expected easing duration (in frames or seconds).
* @return The correct value.
*/
-function easeInQuart (t, b, c, d, p_params) {
+function easeInQuart (t, b, c, d, pParams) {
return c * (t /= d) * t * t * t + b;
}
@@ -194,7 +194,7 @@ function easeInQuart (t, b, c, d, p_params) {
* @param d Expected easing duration (in frames or seconds).
* @return The correct value.
*/
-function easeOutQuart (t, b, c, d, p_params) {
+function easeOutQuart (t, b, c, d, pParams) {
return -c * ((t = t / d - 1) * t * t * t - 1) + b;
}
@@ -207,7 +207,7 @@ function easeOutQuart (t, b, c, d, p_params) {
* @param d Expected easing duration (in frames or seconds).
* @return The correct value.
*/
-function easeInOutQuart (t, b, c, d, p_params) {
+function easeInOutQuart (t, b, c, d, pParams) {
if ((t /= d / 2) < 1)
return c / 2 * t * t * t * t + b;
return -c / 2 * ((t -= 2) * t * t * t - 2) + b;
@@ -222,10 +222,10 @@ function easeInOutQuart (t, b, c, d, p_params) {
* @param d Expected easing duration (in frames or seconds).
* @return The correct value.
*/
-function easeOutInQuart (t, b, c, d, p_params) {
+function easeOutInQuart (t, b, c, d, pParams) {
if (t < d / 2)
- return easeOutQuart (t * 2, b, c / 2, d, p_params);
- return easeInQuart((t * 2) - d, b + c / 2, c / 2, d, p_params);
+ return easeOutQuart (t * 2, b, c / 2, d, pParams);
+ return easeInQuart((t * 2) - d, b + c / 2, c / 2, d, pParams);
}
/**
@@ -237,7 +237,7 @@ function easeOutInQuart (t, b, c, d, p_params) {
* @param d Expected easing duration (in frames or seconds).
* @return The correct value.
*/
-function easeInQuint (t, b, c, d, p_params) {
+function easeInQuint (t, b, c, d, pParams) {
return c * (t /= d) * t * t * t * t + b;
}
@@ -250,7 +250,7 @@ function easeInQuint (t, b, c, d, p_params) {
* @param d Expected easing duration (in frames or seconds).
* @return The correct value.
*/
-function easeOutQuint (t, b, c, d, p_params) {
+function easeOutQuint (t, b, c, d, pParams) {
return c * ((t = t / d - 1) * t * t * t * t + 1) + b;
}
@@ -263,7 +263,7 @@ function easeOutQuint (t, b, c, d, p_params) {
* @param d Expected easing duration (in frames or seconds).
* @return The correct value.
*/
-function easeInOutQuint (t, b, c, d, p_params) {
+function easeInOutQuint (t, b, c, d, pParams) {
if ((t /= d / 2) < 1)
return c / 2 * t * t * t * t * t + b;
return c / 2 * ((t -= 2) * t * t * t * t + 2) + b;
@@ -278,10 +278,10 @@ function easeInOutQuint (t, b, c, d, p_params) {
* @param d Expected easing duration (in frames or seconds).
* @return The correct value.
*/
-function easeOutInQuint (t, b, c, d, p_params) {
+function easeOutInQuint (t, b, c, d, pParams) {
if (t < d / 2)
- return easeOutQuint (t * 2, b, c / 2, d, p_params);
- return easeInQuint((t * 2) - d, b + c / 2, c / 2, d, p_params);
+ return easeOutQuint (t * 2, b, c / 2, d, pParams);
+ return easeInQuint((t * 2) - d, b + c / 2, c / 2, d, pParams);
}
/**
@@ -293,7 +293,7 @@ function easeOutInQuint (t, b, c, d, p_params) {
* @param d Expected easing duration (in frames or seconds).
* @return The correct value.
*/
-function easeInSine (t, b, c, d, p_params) {
+function easeInSine (t, b, c, d, pParams) {
return -c * Math.cos(t / d * (Math.PI / 2)) + c + b;
}
@@ -306,7 +306,7 @@ function easeInSine (t, b, c, d, p_params) {
* @param d Expected easing duration (in frames or seconds).
* @return The correct value.
*/
-function easeOutSine (t, b, c, d, p_params) {
+function easeOutSine (t, b, c, d, pParams) {
return c * Math.sin(t / d * (Math.PI / 2)) + b;
}
@@ -319,7 +319,7 @@ function easeOutSine (t, b, c, d, p_params) {
* @param d Expected easing duration (in frames or seconds).
* @return The correct value.
*/
-function easeInOutSine (t, b, c, d, p_params) {
+function easeInOutSine (t, b, c, d, pParams) {
return -c / 2 * (Math.cos(Math.PI * t / d) - 1) + b;
}
@@ -332,10 +332,10 @@ function easeInOutSine (t, b, c, d, p_params) {
* @param d Expected easing duration (in frames or seconds).
* @return The correct value.
*/
-function easeOutInSine (t, b, c, d, p_params) {
+function easeOutInSine (t, b, c, d, pParams) {
if (t < d / 2)
- return easeOutSine (t * 2, b, c / 2, d, p_params);
- return easeInSine((t * 2) - d, b + c / 2, c / 2, d, p_params);
+ return easeOutSine (t * 2, b, c / 2, d, pParams);
+ return easeInSine((t * 2) - d, b + c / 2, c / 2, d, pParams);
}
/**
@@ -347,7 +347,7 @@ function easeOutInSine (t, b, c, d, p_params) {
* @param d Expected easing duration (in frames or seconds).
* @return The correct value.
*/
-function easeInExpo (t, b, c, d, p_params) {
+function easeInExpo (t, b, c, d, pParams) {
return (t <= 0) ? b : c * Math.pow(2, 10 * (t / d - 1)) + b;
}
@@ -360,7 +360,7 @@ function easeInExpo (t, b, c, d, p_params) {
* @param d Expected easing duration (in frames or seconds).
* @return The correct value.
*/
-function easeOutExpo (t, b, c, d, p_params) {
+function easeOutExpo (t, b, c, d, pParams) {
return (t >= d) ? b + c : c * (-Math.pow(2, -10 * t / d) + 1) + b;
}
@@ -373,7 +373,7 @@ function easeOutExpo (t, b, c, d, p_params) {
* @param d Expected easing duration (in frames or seconds).
* @return The correct value.
*/
-function easeInOutExpo (t, b, c, d, p_params) {
+function easeInOutExpo (t, b, c, d, pParams) {
if (t <= 0)
return b;
if (t >= d)
@@ -392,10 +392,10 @@ function easeInOutExpo (t, b, c, d, p_params) {
* @param d Expected easing duration (in frames or seconds).
* @return The correct value.
*/
-function easeOutInExpo (t, b, c, d, p_params) {
+function easeOutInExpo (t, b, c, d, pParams) {
if (t < d / 2)
- return easeOutExpo (t * 2, b, c / 2, d, p_params);
- return easeInExpo((t * 2) - d, b + c / 2, c / 2, d, p_params);
+ return easeOutExpo (t * 2, b, c / 2, d, pParams);
+ return easeInExpo((t * 2) - d, b + c / 2, c / 2, d, pParams);
}
/**
@@ -407,7 +407,7 @@ function easeOutInExpo (t, b, c, d, p_params) {
* @param d Expected easing duration (in frames or seconds).
* @return The correct value.
*/
-function easeInCirc (t, b, c, d, p_params) {
+function easeInCirc (t, b, c, d, pParams) {
return -c * (Math.sqrt(1 - (t /= d) * t) - 1) + b;
}
@@ -420,7 +420,7 @@ function easeInCirc (t, b, c, d, p_params) {
* @param d Expected easing duration (in frames or seconds).
* @return The correct value.
*/
-function easeOutCirc (t, b, c, d, p_params) {
+function easeOutCirc (t, b, c, d, pParams) {
return c * Math.sqrt(1 - (t = t / d - 1) * t) + b;
}
@@ -433,7 +433,7 @@ function easeOutCirc (t, b, c, d, p_params) {
* @param d Expected easing duration (in frames or seconds).
* @return The correct value.
*/
-function easeInOutCirc (t, b, c, d, p_params) {
+function easeInOutCirc (t, b, c, d, pParams) {
if ((t /= d / 2) < 1)
return -c / 2 * (Math.sqrt(1 - t * t) - 1) + b;
return c / 2 * (Math.sqrt(1 - (t -= 2) * t) + 1) + b;
@@ -448,10 +448,10 @@ function easeInOutCirc (t, b, c, d, p_params) {
* @param d Expected easing duration (in frames or seconds).
* @return The correct value.
*/
-function easeOutInCirc (t, b, c, d, p_params) {
+function easeOutInCirc (t, b, c, d, pParams) {
if (t < d / 2)
- return easeOutCirc (t * 2, b, c / 2, d, p_params);
- return easeInCirc((t * 2) - d, b + c / 2, c / 2, d, p_params);
+ return easeOutCirc (t * 2, b, c / 2, d, pParams);
+ return easeInCirc((t * 2) - d, b + c / 2, c / 2, d, pParams);
}
/**
@@ -465,14 +465,14 @@ function easeOutInCirc (t, b, c, d, p_params) {
* @param p Period.
* @return The correct value.
*/
-function easeInElastic (t, b, c, d, p_params) {
+function easeInElastic (t, b, c, d, pParams) {
if (t <= 0)
return b;
if ((t /= d) >= 1)
return b + c;
- var p = !p_params || isNaN(p_params.period) ? d * .3 : p_params.period;
+ var p = !pParams || isNaN(pParams.period) ? d * .3 : pParams.period;
var s;
- var a = !p_params || isNaN(p_params.amplitude) ? 0 : p_params.amplitude;
+ var a = !pParams || isNaN(pParams.amplitude) ? 0 : pParams.amplitude;
if (!a || a < Math.abs(c)) {
a = c;
s = p / 4;
@@ -493,14 +493,14 @@ function easeInElastic (t, b, c, d, p_params) {
* @param p Period.
* @return The correct value.
*/
-function easeOutElastic (t, b, c, d, p_params) {
+function easeOutElastic (t, b, c, d, pParams) {
if (t <= 0)
return b;
if ((t /= d) >= 1)
return b + c;
- var p = !p_params || isNaN(p_params.period) ? d * .3 : p_params.period;
+ var p = !pParams || isNaN(pParams.period) ? d * .3 : pParams.period;
var s;
- var a = !p_params || isNaN(p_params.amplitude) ? 0 : p_params.amplitude;
+ var a = !pParams || isNaN(pParams.amplitude) ? 0 : pParams.amplitude;
if (!a || a < Math.abs(c)) {
a = c;
s = p / 4;
@@ -521,14 +521,14 @@ function easeOutElastic (t, b, c, d, p_params) {
* @param p Period.
* @return The correct value.
*/
-function easeInOutElastic (t, b, c, d, p_params) {
+function easeInOutElastic (t, b, c, d, pParams) {
if (t <= 0)
return b;
if ((t /= d / 2) >= 2)
return b + c;
- var p = !p_params || isNaN(p_params.period) ? d * (.3 * 1.5) : p_params.period;
+ var p = !pParams || isNaN(pParams.period) ? d * (.3 * 1.5) : pParams.period;
var s;
- var a = !p_params || isNaN(p_params.amplitude) ? 0 : p_params.amplitude;
+ var a = !pParams || isNaN(pParams.amplitude) ? 0 : pParams.amplitude;
if (!a || a < Math.abs(c)) {
a = c;
s = p / 4;
@@ -551,10 +551,10 @@ function easeInOutElastic (t, b, c, d, p_params) {
* @param p Period.
* @return The correct value.
*/
-function easeOutInElastic (t, b, c, d, p_params) {
+function easeOutInElastic (t, b, c, d, pParams) {
if (t < d / 2)
- return easeOutElastic (t * 2, b, c / 2, d, p_params);
- return easeInElastic((t * 2) - d, b + c / 2, c / 2, d, p_params);
+ return easeOutElastic (t * 2, b, c / 2, d, pParams);
+ return easeInElastic((t * 2) - d, b + c / 2, c / 2, d, pParams);
}
/**
@@ -567,8 +567,8 @@ function easeOutInElastic (t, b, c, d, p_params) {
* @param s Overshoot ammount: higher s means greater overshoot (0 produces cubic easing with no
overshoot, and the default value of 1.70158 produces an overshoot of 10 percent).
* @return The correct value.
*/
-function easeInBack (t, b, c, d, p_params) {
- var s = !p_params || isNaN(p_params.overshoot) ? 1.70158 : p_params.overshoot;
+function easeInBack (t, b, c, d, pParams) {
+ var s = !pParams || isNaN(pParams.overshoot) ? 1.70158 : pParams.overshoot;
return c * (t /= d) * t * ((s + 1) * t - s) + b;
}
@@ -582,8 +582,8 @@ function easeInBack (t, b, c, d, p_params) {
* @param s Overshoot ammount: higher s means greater overshoot (0 produces cubic easing with no
overshoot, and the default value of 1.70158 produces an overshoot of 10 percent).
* @return The correct value.
*/
-function easeOutBack (t, b, c, d, p_params) {
- var s = !p_params || isNaN(p_params.overshoot) ? 1.70158 : p_params.overshoot;
+function easeOutBack (t, b, c, d, pParams) {
+ var s = !pParams || isNaN(pParams.overshoot) ? 1.70158 : pParams.overshoot;
return c * ((t = t / d - 1) * t * ((s + 1) * t + s) + 1) + b;
}
@@ -597,8 +597,8 @@ function easeOutBack (t, b, c, d, p_params) {
* @param s Overshoot ammount: higher s means greater overshoot (0 produces cubic easing with no
overshoot, and the default value of 1.70158 produces an overshoot of 10 percent).
* @return The correct value.
*/
-function easeInOutBack (t, b, c, d, p_params) {
- var s = !p_params || isNaN(p_params.overshoot) ? 1.70158 : p_params.overshoot;
+function easeInOutBack (t, b, c, d, pParams) {
+ var s = !pParams || isNaN(pParams.overshoot) ? 1.70158 : pParams.overshoot;
if ((t /= d / 2) < 1)
return c / 2 * (t * t * (((s *= (1.525)) + 1) * t - s)) + b;
return c / 2 * ((t -= 2) * t * (((s *= (1.525)) + 1) * t + s) + 2) + b;
@@ -614,10 +614,10 @@ function easeInOutBack (t, b, c, d, p_params) {
* @param s Overshoot ammount: higher s means greater overshoot (0 produces cubic easing with no
overshoot, and the default value of 1.70158 produces an overshoot of 10 percent).
* @return The correct value.
*/
-function easeOutInBack (t, b, c, d, p_params) {
+function easeOutInBack (t, b, c, d, pParams) {
if (t < d / 2)
- return easeOutBack (t * 2, b, c / 2, d, p_params);
- return easeInBack((t * 2) - d, b + c / 2, c / 2, d, p_params);
+ return easeOutBack (t * 2, b, c / 2, d, pParams);
+ return easeInBack((t * 2) - d, b + c / 2, c / 2, d, pParams);
}
/**
@@ -629,7 +629,7 @@ function easeOutInBack (t, b, c, d, p_params) {
* @param d Expected easing duration (in frames or seconds).
* @return The correct value.
*/
-function easeInBounce (t, b, c, d, p_params) {
+function easeInBounce (t, b, c, d, pParams) {
return c - easeOutBounce (d - t, 0, c, d) + b;
}
@@ -642,7 +642,7 @@ function easeInBounce (t, b, c, d, p_params) {
* @param d Expected easing duration (in frames or seconds).
* @return The correct value.
*/
-function easeOutBounce (t, b, c, d, p_params) {
+function easeOutBounce (t, b, c, d, pParams) {
if ((t /= d) < (1 / 2.75)) {
return c * (7.5625 * t * t) + b;
} else if (t < (2 / 2.75)) {
@@ -663,7 +663,7 @@ function easeOutBounce (t, b, c, d, p_params) {
* @param d Expected easing duration (in frames or seconds).
* @return The correct value.
*/
-function easeInOutBounce (t, b, c, d, p_params) {
+function easeInOutBounce (t, b, c, d, pParams) {
if (t < d / 2)
return easeInBounce (t * 2, 0, c, d) * .5 + b;
else
@@ -679,8 +679,8 @@ function easeInOutBounce (t, b, c, d, p_params) {
* @param d Expected easing duration (in frames or seconds).
* @return The correct value.
*/
-function easeOutInBounce (t, b, c, d, p_params) {
+function easeOutInBounce (t, b, c, d, pParams) {
if (t < d / 2)
- return easeOutBounce (t * 2, b, c / 2, d, p_params);
- return easeInBounce((t * 2) - d, b + c / 2, c / 2, d, p_params);
+ return easeOutBounce (t * 2, b, c / 2, d, pParams);
+ return easeInBounce((t * 2) - d, b + c / 2, c / 2, d, pParams);
}
diff --git a/test/gjs-test-coverage/loadedJSFromResource.js b/test/gjs-test-coverage/loadedJSFromResource.js
index 9a3bd8d9..dca16dd1 100644
--- a/test/gjs-test-coverage/loadedJSFromResource.js
+++ b/test/gjs-test-coverage/loadedJSFromResource.js
@@ -1,2 +1,2 @@
-/* exported mock_function */
-function mock_function() {}
+/* exported mockFunction */
+function mockFunction() {}
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]
diff --git a/modules/overrides/Gio.js b/modules/overrides/Gio.js
index 6cf42896..d26d692b 100644
--- a/modules/overrides/Gio.js
+++ b/modules/overrides/Gio.js
@@ -71,14 +71,14 @@ function _validateFDVariant(variant, fdList) {
throw new Error('Assertion failure: this code should not be reached');
}
-function _proxyInvoker(methodName, sync, inSignature, arg_array) {
+function _proxyInvoker(methodName, sync, inSignature, argArray) {
var replyFunc;
var flags = 0;
var cancellable = null;
let fdList = null;
- /* Convert arg_array to a *real* array */
- arg_array = Array.prototype.slice.call(arg_array);
+ /* Convert argArray to a *real* array */
+ argArray = Array.prototype.slice.call(argArray);
/* The default replyFunc only logs the responses */
replyFunc = _logReply;
@@ -87,18 +87,18 @@ function _proxyInvoker(methodName, sync, inSignature, arg_array) {
var minNumberArgs = signatureLength;
var maxNumberArgs = signatureLength + 4;
- if (arg_array.length < minNumberArgs) {
+ if (argArray.length < minNumberArgs) {
throw new Error(`Not enough arguments passed for method: ${
- methodName}. Expected ${minNumberArgs}, got ${arg_array.length}`);
- } else if (arg_array.length > maxNumberArgs) {
+ methodName}. Expected ${minNumberArgs}, got ${argArray.length}`);
+ } else if (argArray.length > maxNumberArgs) {
throw new Error(`Too many arguments passed for method ${methodName}. ` +
`Maximum is ${maxNumberArgs} including one callback, ` +
'Gio.Cancellable, Gio.UnixFDList, and/or flags');
}
- while (arg_array.length > signatureLength) {
- var argNum = arg_array.length - 1;
- var arg = arg_array.pop();
+ while (argArray.length > signatureLength) {
+ var argNum = argArray.length - 1;
+ var arg = argArray.pop();
if (typeof(arg) == 'function' && !sync) {
replyFunc = arg;
} else if (typeof(arg) == 'number') {
@@ -115,7 +115,7 @@ function _proxyInvoker(methodName, sync, inSignature, arg_array) {
}
const inTypeString = `(${inSignature.join('')})`;
- const inVariant = new GLib.Variant(inTypeString, arg_array);
+ const inVariant = new GLib.Variant(inTypeString, argArray);
if (inTypeString.includes('h')) {
if (!fdList)
throw new Error(`Method ${methodName} with input type containing ` +
@@ -127,7 +127,7 @@ function _proxyInvoker(methodName, sync, inSignature, arg_array) {
try {
const [outVariant, outFdList] =
proxy.call_with_unix_fd_list_finish(result);
- replyFunc(outVariant.deep_unpack(), null, outFdList);
+ replyFunc(outVariant.deepUnpack(), null, outFdList);
} catch (e) {
replyFunc([], e, null);
}
@@ -137,8 +137,8 @@ function _proxyInvoker(methodName, sync, inSignature, arg_array) {
const [outVariant, outFdList] = this.call_with_unix_fd_list_sync(
methodName, inVariant, flags, -1, fdList, cancellable);
if (fdList)
- return [outVariant.deep_unpack(), outFdList];
- return outVariant.deep_unpack();
+ return [outVariant.deepUnpack(), outFdList];
+ return outVariant.deepUnpack();
}
return this.call_with_unix_fd_list(methodName, inVariant, flags, -1, fdList,
@@ -164,13 +164,13 @@ function _makeProxyMethod(method, sync) {
};
}
-function _convertToNativeSignal(proxy, sender_name, signal_name, parameters) {
- Signals._emit.call(proxy, signal_name, sender_name, parameters.deep_unpack());
+function _convertToNativeSignal(proxy, senderName, signalName, parameters) {
+ Signals._emit.call(proxy, signalName, senderName, parameters.deepUnpack());
}
function _propertyGetter(name) {
let value = this.get_cached_property(name);
- return value ? value.deep_unpack() : null;
+ return value ? value.deepUnpack() : null;
}
function _propertySetter(name, signature, value) {
@@ -318,13 +318,13 @@ function _makeOutSignature(args) {
return `${ret})`;
}
-function _handleMethodCall(info, impl, method_name, parameters, invocation) {
+function _handleMethodCall(info, impl, methodName, parameters, invocation) {
// prefer a sync version if available
- if (this[method_name]) {
+ if (this[methodName]) {
let retval;
try {
const fdList = invocation.get_message().get_unix_fd_list();
- retval = this[method_name](...parameters.deep_unpack(), fdList);
+ retval = this[methodName](...parameters.deepUnpack(), fdList);
} catch (e) {
if (e instanceof GLib.Error) {
invocation.return_gerror(e);
@@ -334,7 +334,7 @@ function _handleMethodCall(info, impl, method_name, parameters, invocation) {
// likely to be a normal JS error
name = `org.gnome.gjs.JSError.${name}`;
}
- logError(e, `Exception in method call: ${method_name}`);
+ logError(e, `Exception in method call: ${methodName}`);
invocation.return_dbus_error(name, e.message);
}
return;
@@ -347,7 +347,7 @@ function _handleMethodCall(info, impl, method_name, parameters, invocation) {
let outFdList = null;
if (!(retval instanceof GLib.Variant)) {
// attempt packing according to out signature
- let methodInfo = info.lookup_method(method_name);
+ let methodInfo = info.lookup_method(methodName);
let outArgs = methodInfo.out_args;
let outSignature = _makeOutSignature(outArgs);
if (outSignature.includes('h') &&
@@ -366,29 +366,29 @@ function _handleMethodCall(info, impl, method_name, parameters, invocation) {
invocation.return_dbus_error('org.gnome.gjs.JSError.ValueError',
'Service implementation returned an incorrect value type');
}
- } else if (this[`${method_name}Async`]) {
+ } else if (this[`${methodName}Async`]) {
const fdList = invocation.get_message().get_unix_fd_list();
- this[`${method_name}Async`](parameters.deep_unpack(), invocation, fdList);
+ this[`${methodName}Async`](parameters.deepUnpack(), invocation, fdList);
} else {
- log(`Missing handler for DBus method ${method_name}`);
+ log(`Missing handler for DBus method ${methodName}`);
invocation.return_gerror(new Gio.DBusError({
code: Gio.DBusError.UNKNOWN_METHOD,
- message: `Method ${method_name} is not implemented`,
+ message: `Method ${methodName} is not implemented`,
}));
}
}
-function _handlePropertyGet(info, impl, property_name) {
- let propInfo = info.lookup_property(property_name);
- let jsval = this[property_name];
+function _handlePropertyGet(info, impl, propertyName) {
+ let propInfo = info.lookup_property(propertyName);
+ let jsval = this[propertyName];
if (jsval != undefined)
return new GLib.Variant(propInfo.signature, jsval);
else
return null;
}
-function _handlePropertySet(info, impl, property_name, new_value) {
- this[property_name] = new_value.deep_unpack();
+function _handlePropertySet(info, impl, propertyName, newValue) {
+ this[propertyName] = newValue.deepUnpack();
}
function _wrapJSObject(interfaceInfo, jsObj) {
@@ -400,14 +400,14 @@ function _wrapJSObject(interfaceInfo, jsObj) {
info.cache_build();
var impl = new GjsPrivate.DBusImplementation({g_interface_info: info});
- impl.connect('handle-method-call', function(impl, method_name, parameters, invocation) {
- return _handleMethodCall.call(jsObj, info, impl, method_name, parameters, invocation);
+ impl.connect('handle-method-call', function(impl, methodName, parameters, invocation) {
+ return _handleMethodCall.call(jsObj, info, impl, methodName, parameters, invocation);
});
- impl.connect('handle-property-get', function(impl, property_name) {
- return _handlePropertyGet.call(jsObj, info, impl, property_name);
+ impl.connect('handle-property-get', function(impl, propertyName) {
+ return _handlePropertyGet.call(jsObj, info, impl, propertyName);
});
- impl.connect('handle-property-set', function(impl, property_name, value) {
- return _handlePropertySet.call(jsObj, info, impl, property_name, value);
+ impl.connect('handle-property-set', function(impl, propertyName, value) {
+ return _handlePropertySet.call(jsObj, info, impl, propertyName, value);
});
return impl;